==> php74-fengoffice-3.11.6.8.tgz: share/fengoffice/plugins/mail/language/en_us/lang.php <==
<?php return array(
	'mail' => 'Mail',
	'mails' => 'Mails',
	'linked mail tab'=>'Emails',
    'subscribed notification mail' => 'Subscribed to Mail \'{0}\'',
    'subscribed notification mail desc' => 'You have been subscribed to the Mail \'{0}\' by {1}.',
	'user config option name mails_per_page' => 'Mails per page',
  	'user config option desc mails_per_page' => 'Amount of emails listed (avoid 0 and negative numbers). Take into account that the larger the number, the more time it will take to load the emails.',
	'user config option name check_attach_word' => 'Check attach word',
	'user config option desc check_attach_word' => 'Notifies the user when sending an email if it has nothing attached but contains the word attach',
	'user config option name check_is_defult_account' => 'Check the account selected to send the email ',
	'user config option desc check_is_defult_account' => 'Checks whether the account selected to send the email is the default account and notifies the user if is not',
	'config option name use_mail_accounts_to_send_nots' => 'Send notifications using the sender\'s email account',
	'config option desc use_mail_accounts_to_send_nots' => 'If this option is enabled and the sender has defined an email account then this user\'s notifications will be sent using his/her email account.',
	'by subject or address' => 'Search by subject or address',
	'are you sure you want to send the email using account x' => 'Are you sure you want to send the email using account {0} ?',
	'field Objects to' => 'To',
	'field Objects cc' => 'CC',
	'field Objects bcc' => 'BCC',
	'field Objects body_html' => 'Html body',
	'field Objects body_plain' => 'Plain Body',
	'classify attachments' => 'Classify attachments',
	'mail status col tooltip' => 'Shows if email has been replied or forwarded',
	'classify only attachments' => 'Classify only attachments',
	'incoming ssl verify peer' => 'Verify SSL certificate',
	'incoming ssl verify peer desc' => 'Specifies if the server requires clients to present a valid certificate to connect. Server instances can allow clients to connect with or without providing a valid certificate.',
	
	'gmail authentication failed need unlockcaptcha' => 'Authentication with gmail.com failed, you need to unblock the access to your account using the unlock captcha feature',
	'more information can be found in' => 'More information can be found in',
	'solve gmail login issues' => 'Solving Gmail login issues',
	'unlock captcha' => 'Unlock captcha',
	'allowing less secure apps to access your account' => 'Allowing less secure apps to access your account',
	'if auth problem persists' => 'If the authentication problem is still present please follow these instructions:',
	'after completing the process please try using the fetch imap folders link to check the connection' => 'After completing the process please try using the Fetch imap folders link below to check the connection.',
	'error connecting to mail server' => 'Error occurred when trying to connect with the email server.',
	'mail server response' => 'Mail server response',
	'ensure that your password is correct' => 'Please ensure that the entered password is correct.',
	'connection data is correct' => 'Connection data is correct.',
	'check connection data' => 'Check connection data',
	'check connection data link description' => 'After filling the account configuration fields you can test the connection with the email server.',
    'user config option name default_mail_font_size' => 'Font size by default for emails',
    'user config option desc default_mail_font_size' => 'Font size by default for write the content of the emails (avoid numbers lower than 8 and greather than 72)',
	'success mail enqueued' => 'Email successfully enqueued for sending',
	'config option name send_outbox_emails_in_background' => 'Send emails in background',
	'config option desc send_outbox_emails_in_background' => 'If this option is enabled the emails will be sent in a separate process, allowing the user to work faster. Emails will be put in outbox and sent by a process triggered in background.',
	'select a provider' => 'Select a provider',
	'connect to' => 'Connect to',
	'basic' => 'Basic',
	'oauth2' => 'External provider',
	'auth method' => 'Authentication method',
	'use oauth2' => 'Use OAUTH2'
);

==> php74-fengoffice-3.11.8.0.tgz: share/fengoffice/plugins/mail/language/en_us/lang.php <==
<?php return array(
	'mail' => 'Mail',
	'mails' => 'Mails',
	'linked mail tab'=>'Emails',
    'subscribed notification mail' => 'Subscribed to Mail \'{0}\'',
    'subscribed notification mail desc' => 'You have been subscribed to the Mail \'{0}\' by {1}.',
	'user config option name mails_per_page' => 'Mails per page',
  	'user config option desc mails_per_page' => 'Amount of emails listed (avoid 0 and negative numbers). Take into account that the larger the number, the more time it will take to load the emails.',
	'user config option name check_attach_word' => 'Check attach word',
	'user config option desc check_attach_word' => 'Notifies the user when sending an email if it has nothing attached but contains the word attach',
	'user config option name check_is_defult_account' => 'Check the account selected to send the email ',
	'user config option desc check_is_defult_account' => 'Checks whether the account selected to send the email is the default account and notifies the user if is not',
	'config option name use_mail_accounts_to_send_nots' => 'Send notifications using the sender\'s email account',
	'config option desc use_mail_accounts_to_send_nots' => 'If this option is enabled and the sender has defined an email account then this user\'s notifications will be sent using his/her email account.',
	'by subject or address' => 'Search by subject or address',
	'are you sure you want to send the email using account x' => 'Are you sure you want to send the email using account {0} ?',
	'field Objects to' => 'To',
	'field Objects cc' => 'CC',
	'field Objects bcc' => 'BCC',
	'field Objects body_html' => 'Html body',
	'field Objects body_plain' => 'Plain Body',
	'classify attachments' => 'Classify attachments',
	'mail status col tooltip' => 'Shows if email has been replied or forwarded',
	'classify only attachments' => 'Classify only attachments',
	'incoming ssl verify peer' => 'Verify SSL certificate',
	'incoming ssl verify peer desc' => 'Specifies if the server requires clients to present a valid certificate to connect. Server instances can allow clients to connect with or without providing a valid certificate.',
	
	'gmail authentication failed need unlockcaptcha' => 'Authentication with gmail.com failed, you need to unblock the access to your account using the unlock captcha feature',
	'more information can be found in' => 'More information can be found in',
	'solve gmail login issues' => 'Solving Gmail login issues',
	'unlock captcha' => 'Unlock captcha',
	'allowing less secure apps to access your account' => 'Allowing less secure apps to access your account',
	'if auth problem persists' => 'If the authentication problem is still present please follow these instructions:',
	'after completing the process please try using the fetch imap folders link to check the connection' => 'After completing the process please try using the Fetch imap folders link below to check the connection.',
	'error connecting to mail server' => 'Error occurred when trying to connect with the email server.',
	'mail server response' => 'Mail server response',
	'ensure that your password is correct' => 'Please ensure that the entered password is correct.',
	'connection data is correct' => 'Connection data is correct.',
	'check connection data' => 'Check connection data',
	'check connection data link description' => 'After filling the account configuration fields you can test the connection with the email server.',
    'user config option name default_mail_font_size' => 'Font size by default for emails',
    'user config option desc default_mail_font_size' => 'Font size by default for write the content of the emails (avoid numbers lower than 8 and greather than 72)',
	'success mail enqueued' => 'Email successfully enqueued for sending',
	'config option name send_outbox_emails_in_background' => 'Send emails in background',
	'config option desc send_outbox_emails_in_background' => 'If this option is enabled the emails will be sent in a separate process, allowing the user to work faster. Emails will be put in outbox and sent by a process triggered in background.',
	'select a provider' => 'Select a provider',
	'connect to' => 'Connect to',
	'basic' => 'Basic',
	'oauth2' => 'External provider',
	'auth method' => 'Authentication method',
	'use oauth2' => 'Use OAUTH2',
	'Error: The email size exceeds the server allowed limit.' => 'The total size of the attachment/s exceeds the allowed server limit.',
);
